@if not-imported("import_once_func") { @import "import_once_func"; }
/**
 * Fonts
 */
$font-family: "livory", -apple-system,system-ui,"Segoe UI",Roboto,Oxygen-Sans,Ubuntu,Cantarell,"Helvetica Neue",sans-serif;
$font-family-alternate: "Montserrat", -apple-system,system-ui,"Segoe UI",Roboto,Oxygen-Sans,Ubuntu,Cantarell,"Helvetica Neue",sans-serif;
$font-family-minion: "Montserrat", -apple-system,system-ui,"Segoe UI",Roboto,Oxygen-Sans,Ubuntu,Cantarell,"Helvetica Neue",sans-serif;
$font-family-alternate-sc: "FFEurekaStdSc", -apple-system,system-ui,"Segoe UI",Roboto,Oxygen-Sans,Ubuntu,Cantarell,"Helvetica Neue",sans-serif;
$font-family-handwriting: "Carpenter", -apple-system,system-ui,"Segoe UI",Roboto,Oxygen-Sans,Ubuntu,Cantarell,"Helvetica Neue",sans-serif;
$font-family-icon: "icomoon";

/**
 * Colors
 */
$color-bg-primary: #442e2c;
$color-bg-secondary: #aaa194;
$color-bg-tertiary: #dddad5;
$color-bg-quaternary: #C48F3A;
$color-bg-quaternary: #C69749;
$color-bg-quinary: #C2BCB2;
$color-bg-senary: #EDEBE8;
$color-bg-lightergrey: #f3f3f3;
$color-bg-lightgrey: #eaeaea;
$color-bg-lightplatin: mix($color-bg-secondary,#fff,20%);
$color-bg-lightplatin: rgb(244,244,241);
$color-bg-lightbrown: mix($color-bg-primary,#fff,70%);
$color-bg-footer: #c7c1b8;
$color-bg-footer2: #f4f4f1;

$color-white: #ffffff;
$color-black: #000000;

$color-list-icon: #000000;

$color-stroke-grey: #cacaca;
$color-stroke-light: #ffffff;

$color-shadow: rgba(#0a5680,0.75);

$color-nav: $color-white;
$color-nav-invert: $color-black;
$color-nav-hover: $color-bg-primary;
$color-nav-mobile: #ffffff;
$color-headline: $color-bg-secondary;
$color-headline-invert: #ffffff;
$color-link: $color-bg-secondary;
$color-link-alt: #A69D8F;
$color-text: $color-bg-primary;
$color-text-info: $color-bg-quinary;
$color-text-breadcrumb: #666666;
$color-text-grey: #C4C0B7;
$color-text-invert: #ffffff;
$color-text-alt: $color-bg-secondary;
$color-text-light: #dfddd7;
$color-text-footer: #ffffff;
$color-text-summary: #8D877C;

/**
 * Breakpoints
 */
$breakpoint-desktop: 1200px;
$breakpoint-tablet: 900px;
$breakpoint-mobile: 599px;

/**
 * Font sizes and defaults
 */
$font-size-default: 20px;
$font-size-mainnav: 16px / $font-size-default * 100%;

$font-weight-default: 400;
$font-weight-bold: 700;

$line-height-default: 1.2;

/**
 * Shadow
 */
$text-shadow-image: 0 2px 4px #000;

/**
 * Gutters
 */
$gutter-default: floor((1 / 1200) * 1000000) / 1000000 * 20 * 100%;
//$gutter-default: 20px / $font-size-default * 1rem;


/**
 * Forms
 */
// Radius
$field-radius: 0;

// Colors
$field-background-color: mix(#ffffff,$color-bg-quinary,80%);
$field-background-color-ro: #eeeeee;
$field-background-color-hl: mix($field-background-color,$color-bg-quinary,70%);
$button-background-color: $color-bg-tertiary;
$button-background-color-hl: $color-bg-secondary;
$button-o-background-color-hl: $color-bg-secondary;

$field-border-color: #CFCAC1;
$field-border-color-hl: mix(#fff,$color-bg-quaternary,50%);
$button-border-color: $color-bg-tertiary;
$button-border-color-hl: $color-bg-secondary;
$button-o-border-color: $color-bg-tertiary;
$button-o-border-color-hl: $color-bg-secondary;

$placeholder-color: $color-link-alt;
$field-color: $color-text;
$button-color: $color-text-invert;
$button-color-hl: $color-text-invert;
$button-o-color: $color-bg-tertiary;
$button-o-color-hl: #ffffff;
$label-color: inherit;

// Sizes & Paddings
$field-padding-vertical: 3px;
$field-padding-horizontal: 6px;
$field-padding: $field-padding-vertical $field-padding-horizontal;
$field-height: 35px;
$field-border-width: 1px;
$button-padding-vertical: 3px;
$button-padding-horizontal: 20px;
$button-padding: $button-padding-vertical $button-padding-horizontal;
$button-height: 35px;
$button-border-width: 1px;

$font-size-field: 14px / $font-size-default * 100%;
$font-size-placeholder: 12px / $font-size-default * 1rem;
$font-size-button: 16px / $font-size-default * 100%;

// Font
$font-family-form: $font-family;
