<?php

/**
 * TeamList for Contao
 *
 * Copyright (c) 2016 Benjamin Roth
 *
 * @license LGPL-3.0+
 */


/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_esm_team_group']['title'][0] = "Team-Kategorie";
$GLOBALS['TL_LANG']['tl_esm_team_group']['title'][1] = "Kategoriename des Teams";

/**
 * Legends
 */
$GLOBALS['TL_LANG']['tl_esm_team_group']['title_legend']      = 'Grundeinstellungen';

/**
 * Buttons
 */
$GLOBALS['TL_LANG']['tl_esm_team_group']['new']               = array('Neue Team-Kategorie', 'Eine neue Team-Kategorie hinzufügen');
$GLOBALS['TL_LANG']['tl_esm_team_group']['show']              = array('Team-Kategoriedetails', 'Details der Team-Kategorie ID %s anzeigen');
$GLOBALS['TL_LANG']['tl_esm_team_group']['edit']              = array('Team-Kategorie bearbeiten', 'Team-Kategorie ID %s bearbeiten');
$GLOBALS['TL_LANG']['tl_esm_team_group']['copy']              = array('Team-Kategorie duplizieren', 'Team-Kategorie ID %s duplizieren');
$GLOBALS['TL_LANG']['tl_esm_team_group']['delete']            = array('Team-Kategorie löschen', 'Team-Kategorie ID %s löschen');
