<?php

return array(
	'label' => array(
		'Zentrierter Inhaltsbereich mit halbseitigem Bild Ende',
		'Beendet einen zentrierten Inhaltsbereich',
	),
	'types' => array('content', 'module'),
	'wrapper' => array(
		'type' => 'stop',
	),
	'fields' => array(),
);
