.ico {
  display: inline-block;
  width: 1em;
  height: 1em;
  stroke-width: 0;
  stroke: currentColor;
  fill: currentColor;
}

/* ==========================================
Single-colored icons can be modified like so:
.ico-name {
  font-size: 32px;
  color: red;
}
========================================== */

.ico-durbach_signet {
  width: 1.9794921875em;
}

.ico-durbacher_logo {
  width: 7.666015625em;
}
