/* montserrat-regular - latin */
@font-face {
  font-family: 'Montserrat';
  font-style: normal;
  font-weight: 400;
  font-display: swap;
  src: url('../../fonts/google/montserrat-v15-latin-regular.eot'); /* IE9 Compat Modes */
  src: local(''),
  url('../../fonts/google/montserrat-v15-latin-regular.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
  url('../../fonts/google/montserrat-v15-latin-regular.woff2') format('woff2'), /* Super Modern Browsers */
  url('../../fonts/google/montserrat-v15-latin-regular.woff') format('woff'), /* Modern Browsers */
  url('../../fonts/google/montserrat-v15-latin-regular.ttf') format('truetype'), /* Safari, Android, iOS */
  url('../../fonts/google/montserrat-v15-latin-regular.svg#Montserrat') format('svg'); /* Legacy iOS */
}
/* montserrat-600 - latin */
@font-face {
  font-family: 'Montserrat';
  font-style: normal;
  font-weight: 600;
  src: url('../../fonts/google/montserrat-v25-latin-600.eot'); /* IE9 Compat Modes */
  src: local(''),
  url('../../fonts/google/montserrat-v25-latin-600.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
  url('../../fonts/google/montserrat-v25-latin-600.woff2') format('woff2'), /* Super Modern Browsers */
  url('../../fonts/google/montserrat-v25-latin-600.woff') format('woff'), /* Modern Browsers */
  url('../../fonts/google/montserrat-v25-latin-600.ttf') format('truetype'), /* Safari, Android, iOS */
  url('../../fonts/google/montserrat-v25-latin-600.svg#Montserrat') format('svg'); /* Legacy iOS */
}
/* montserrat-600italic - latin */
/*@font-face {
  font-family: 'Montserrat';
  font-style: italic;
  font-weight: 600;
  src: url('../../fonts/google/montserrat-v25-latin-600italic.eot'); !* IE9 Compat Modes *!
  src: local(''),
  url('../../fonts/google/montserrat-v25-latin-600italic.eot?#iefix') format('embedded-opentype'), !* IE6-IE8 *!
  url('../../fonts/google/montserrat-v25-latin-600italic.woff2') format('woff2'), !* Super Modern Browsers *!
  url('../../fonts/google/montserrat-v25-latin-600italic.woff') format('woff'), !* Modern Browsers *!
  url('../../fonts/google/montserrat-v25-latin-600italic.ttf') format('truetype'), !* Safari, Android, iOS *!
  url('../../fonts/google/montserrat-v25-latin-600italic.svg#Montserrat') format('svg'); !* Legacy iOS *!
}*/
/* montserrat-700 - latin */
@font-face {
  font-family: 'Montserrat';
  font-style: normal;
  font-weight: 700;
  font-display: swap;
  src: url('../../fonts/google/montserrat-v15-latin-700.eot'); /* IE9 Compat Modes */
  src: local(''),
  url('../../fonts/google/montserrat-v15-latin-700.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
  url('../../fonts/google/montserrat-v15-latin-700.woff2') format('woff2'), /* Super Modern Browsers */
  url('../../fonts/google/montserrat-v15-latin-700.woff') format('woff'), /* Modern Browsers */
  url('../../fonts/google/montserrat-v15-latin-700.ttf') format('truetype'), /* Safari, Android, iOS */
  url('../../fonts/google/montserrat-v15-latin-700.svg#Montserrat') format('svg'); /* Legacy iOS */
}

/* source-serif-pro-regular - latin */
@font-face {
  font-family: 'Source Serif Pro';
  font-style: normal;
  font-weight: 400;
  font-display: swap;
  src: url('../../fonts/google/source-serif-pro-v11-latin-regular.eot'); /* IE9 Compat Modes */
  src: local(''),
  url('../../fonts/google/source-serif-pro-v11-latin-regular.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
  url('../../fonts/google/source-serif-pro-v11-latin-regular.woff2') format('woff2'), /* Super Modern Browsers */
  url('../../fonts/google/source-serif-pro-v11-latin-regular.woff') format('woff'), /* Modern Browsers */
  url('../../fonts/google/source-serif-pro-v11-latin-regular.ttf') format('truetype'), /* Safari, Android, iOS */
  url('../../fonts/google/source-serif-pro-v11-latin-regular.svg#SourceSerifPro') format('svg'); /* Legacy iOS */
}
/* source-serif-pro-600 - latin */
@font-face {
  font-family: 'Source Serif Pro';
  font-style: normal;
  font-weight: 600;
  font-display: swap;
  src: url('../../fonts/google/source-serif-pro-v11-latin-600.eot'); /* IE9 Compat Modes */
  src: local(''),
  url('../../fonts/google/source-serif-pro-v11-latin-600.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
  url('../../fonts/google/source-serif-pro-v11-latin-600.woff2') format('woff2'), /* Super Modern Browsers */
  url('../../fonts/google/source-serif-pro-v11-latin-600.woff') format('woff'), /* Modern Browsers */
  url('../../fonts/google/source-serif-pro-v11-latin-600.ttf') format('truetype'), /* Safari, Android, iOS */
  url('../../fonts/google/source-serif-pro-v11-latin-600.svg#SourceSerifPro') format('svg'); /* Legacy iOS */
}
/* source-serif-pro-700 - latin */
@font-face {
  font-family: 'Source Serif Pro';
  font-style: normal;
  font-weight: 700;
  font-display: swap;
  src: url('../../fonts/google/source-serif-pro-v11-latin-700.eot'); /* IE9 Compat Modes */
  src: local(''),
  url('../../fonts/google/source-serif-pro-v11-latin-700.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
  url('../../fonts/google/source-serif-pro-v11-latin-700.woff2') format('woff2'), /* Super Modern Browsers */
  url('../../fonts/google/source-serif-pro-v11-latin-700.woff') format('woff'), /* Modern Browsers */
  url('../../fonts/google/source-serif-pro-v11-latin-700.ttf') format('truetype'), /* Safari, Android, iOS */
  url('../../fonts/google/source-serif-pro-v11-latin-700.svg#SourceSerifPro') format('svg'); /* Legacy iOS */
}