@font-face {
  font-family: 'icomoon';
  src:  url('../../fonts/icomoon.eot?q0bly');
  src:  url('../../fonts/icomoon.eot?q0bly#iefix') format('embedded-opentype'),
    url('../../fonts/icomoon.woff2?q0bly') format('woff2'),
    url('../../fonts/icomoon.ttf?q0bly') format('truetype'),
    url('../../fonts/icomoon.woff?q0bly') format('woff'),
    url('../../fonts/icomoon.svg?q0bly#icomoon') format('svg');
  font-weight: normal;
  font-style: normal;
  font-display: block;
}

.ico {
  /* use !important to prevent issues with browser extensions that change fonts */
  font-family: 'icomoon' !important;
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;

  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.ico-keyboard_arrow_down:before {
  content: "\e900";
}
.ico-keyboard_arrow_left:before {
  content: "\e901";
}
.ico-keyboard_arrow_right:before {
  content: "\e902";
}
.ico-keyboard_arrow_up:before {
  content: "\e903";
}
.ico-arrow_back_ios:before {
  content: "\e904";
}
.ico-arrow_forward_ios:before {
  content: "\e905";
}
.ico-zoom_in:before {
  content: "\e906";
}
